//
//  EventDetailViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 7/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class EventDetailViewController: UIViewController {

    /**           **
     ** Variables **
     **           **/
    
    var event : Event!
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var imageView: UIImageView!
    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var joinButton: UIButton!
    
    
    /**          **
     **  Actions **
     **          **/
    
    //Acció que realitzem al fer tap sobre el joinButton
    @IBAction func joinButton(_ sender: UIButton) {
        
        let query = PFQuery(className: "JoinEvent")
        query.whereKey("userId", equalTo: PFUser.current()?.objectId! as Any)
        query.whereKey("eventId", equalTo: self.event.eventId)
        query.findObjectsInBackground { (objects, error) in
            if let objects = objects {
                if objects != [] {
                    for object in objects {
                        //Esborrem la relació
                        object.deleteInBackground(block: { (success, error) in
                            if error == nil {
                                self.joinButton.setTitle("Join", for: .normal)
                                self.joinButton.backgroundColor = UIColor(red: 0/255, green: 128/255, blue: 64/255, alpha: 1.0)
                            } else {
                                print(error!.localizedDescription)
                            }
                        })
                    }
                } else {
                    let joinEvent = PFObject(className: "JoinEvent")
                    joinEvent["userId"] = PFUser.current()?.objectId
                    joinEvent["eventId"] = self.event.eventId
                    //Guardem la relacio
                    joinEvent.saveInBackground(block: { (success, error) in
                        if error == nil {
                            self.joinButton.setTitle("Not Join", for: .normal)
                            self.joinButton.backgroundColor = UIColor(red: 165/255, green: 4/255, blue: 7/255, alpha: 1.0)
                        } else {
                            print(error!.localizedDescription)
                        }
                    })
                    
                }
            }
        }
    }
    
    /**           **
     ** Functions **
     **           **/
    
    //Cridem aquesta funció un cop la view ha estat carregada
    override func viewDidLoad() {
        super.viewDidLoad()

        //Carreguem la imatge de l'event
        self.fillEventImage()
    }
    
    //Cridem aquesta funció abans que aparegui la view
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        //Ens preguntem: estem seguin l'event?
        self.isJoin()
    }
    
    //Carreguem la imatge de l'event
    func fillEventImage(){
        self.imageView.image = self.event.image
    }
    
    //Pintem el buttonJoin de verd o vermell segons isJoin
    func isJoin(){
        
        let query = PFQuery(className: "JoinEvent")
        query.whereKey("userId", equalTo: PFUser.current()?.objectId! as Any)
        query.whereKey("eventId", equalTo: self.event.eventId)
        query.findObjectsInBackground { (objects, error) in
            if let objects = objects {
                if objects != [] {
                    self.joinButton.setTitle("Not Join", for: .normal)
                    self.joinButton.backgroundColor = UIColor(red: 165/255, green: 4/255, blue: 7/255, alpha: 1.0)
                } else {
                    self.joinButton.setTitle("Join", for: .normal)
                    self.joinButton.backgroundColor = UIColor(red: 0/255, green: 128/255, blue: 64/255, alpha: 1.0)
                }
            } else {
                print(error!.localizedDescription)
            }
        }
    }

}

/**            **
 ** Extensions **
 **            **/

extension EventDetailViewController : UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 5
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "detailCell", for: indexPath) as! EventDetailViewCell
        
        switch indexPath.row {
        case 0:
            cell.keyLabel.text = "Title:"
            cell.valueLabel.text = self.event.title
        case 1:
            cell.keyLabel.text = "Description:"
            cell.valueLabel.text = self.event.descrip
        case 2:
            cell.keyLabel.text = "Category:"
            cell.valueLabel.text = self.event.category
        case 3:
            cell.keyLabel.text = "Location:"
            cell.valueLabel.text = self.event.location
        case 4:
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            cell.keyLabel.text = "Date:"
            cell.valueLabel.text = formatter.string(from: self.event.date)
        default:
            break
        }
        return cell
    }
}

extension EventDetailViewController : UITableViewDelegate {
    
}

