//
//  LocationViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 14/5/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import MapKit

class LocationViewController: UIViewController {

    /**           **
     ** Variables **
     **           **/
    
    var searchCompleter = MKLocalSearchCompleter()
    var searchResults = [MKLocalSearchCompletion]()
    var location : MKPlacemark?
    var image : UIImage?
    var eventTitle : String?
    var eventDescrip : String?
    var category : String?
    var date : String?
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var searchResultsTableView: UITableView!
    
    /**           **
     ** Functions **
     **           **/
    
    //Cridem funcions un cop la view esta carregada
    override func viewDidLoad() {
        super.viewDidLoad()
        
        searchCompleter.delegate = self
    }
    
    //Preparem la transició cap a NewEvent
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromLocationToNewEvent" {
            if let newEventViewController = segue.destination as? NewEventViewController {
                if self.location != nil{
                    newEventViewController.location = self.location
                }
                if self.image != nil{
                    newEventViewController.image = self.image
                }
                if self.eventTitle != nil{
                    print(self.eventTitle!)
                    newEventViewController.eventTitle = self.eventTitle
                }
                if self.eventDescrip != nil{
                    newEventViewController.eventDescrip = self.eventDescrip
                }
                if self.category != nil{
                    newEventViewController.category = self.category
                }
                if self.date != nil{
                    newEventViewController.date = self.date
                }
            }
        }
    }

}

/**            **
 ** Extensions **
 **            **/

//Funcions necesaries per a poder cercar el text i retornar una location.
extension LocationViewController: UISearchBarDelegate {
    
    func searchBar(_ searchBar: UISearchBar, textDidChange searchText: String) {
        
        searchCompleter.queryFragment = searchText
    }
}

extension LocationViewController: MKLocalSearchCompleterDelegate {
    
    func completerDidUpdateResults(_ completer: MKLocalSearchCompleter) {
        searchResults = completer.results
        searchResultsTableView.reloadData()
    }
    
    func completer(_ completer: MKLocalSearchCompleter, didFailWithError error: Error) {
        
    }
}

extension LocationViewController: UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return searchResults.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let searchResult = searchResults[indexPath.row]
        let cell = UITableViewCell(style: .subtitle, reuseIdentifier: nil)
        cell.textLabel?.text = searchResult.title
        cell.detailTextLabel?.text = searchResult.subtitle
        return cell
    }
}

extension LocationViewController: UITableViewDelegate {
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        
        let completion = searchResults[indexPath.row]
        
        let searchRequest = MKLocalSearchRequest(completion: completion)
        let search = MKLocalSearch(request: searchRequest)
        search.start { (response, error) in
            self.location = (response?.mapItems[0].placemark)
            self.performSegue(withIdentifier: "fromLocationToNewEvent", sender: self.location)
        }
    }
    
    
}
