//
//  MainViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 4/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class MainViewController: UIViewController, UINavigationControllerDelegate, UIImagePickerControllerDelegate, UIPickerViewDelegate, UIPickerViewDataSource {

    /**           **
     ** Variables **
     **           **/
    
    var events : [Event] = []
    var categories : Category = Category()
    var categoryPicker = UIPickerView()
    var locations : Location = Location()
    var locationPicker = UIPickerView()
    var activityIndicator : UIActivityIndicatorView!
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var menuButton: UIBarButtonItem!
    @IBOutlet weak var categoryTextField: UITextField!
    @IBOutlet weak var locationTextField: UITextField!
    @IBOutlet weak var dateTextField: UITextField!
    
    /**          **
     **  Actions **
     **          **/
    
    @IBAction func findButton(_ sender: UIButton) {
        //Hacer la transicion a la pantalla de login cuando registro OK
        //self.performSegue(withIdentifier: "fromMainToResult", sender: nil)
        //_ = EventsFactory.sharedInstance.getEvents()
        self.findEvents()
    }
    
    @IBAction func newEventButton(_ sender: UIButton) {
        //Hacer la transicion a la pantalla de login cuando registro OK
        self.performSegue(withIdentifier: "fromMainToNewEvent", sender: nil)
    }

    //DatePicker
    @IBAction func dateTextField(_ sender: UITextField) {
        
        //Config datePicker
        let datePickerView: UIDatePicker = UIDatePicker()
        datePickerView.datePickerMode = UIDatePickerMode.dateAndTime
        datePickerView.minimumDate = NSDate() as Date
        datePickerView.backgroundColor = .white
        
        //Config button
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.done, target: self, action: #selector(saveDatePicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        let cancelButton = UIBarButtonItem(title: "Cancel", style: UIBarButtonItemStyle.plain, target: self, action: #selector(cancelDatePicker))
        toolBar.setItems([saveButton, space, cancelButton], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        sender.inputView = datePickerView
        sender.inputAccessoryView = toolBar
        datePickerView.addTarget(self, action: #selector(UserProfileViewController.datePickerValueChanged), for: UIControlEvents.valueChanged)
        
    }

    /**           **
     ** Functions **
     **           **/

    //Cridem funcions un cop la view ja esta carregada
    override func viewDidLoad() {
        super.viewDidLoad()
       
        //animacio del buttonMenu
        if self.revealViewController() != nil {
            self.menuButton.target = self.revealViewController()
            self.menuButton.action = #selector(SWRevealViewController.revealToggle(_:))
            self.view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
        }
        
        //Bordes dels textFields
        self.topBottomBorder(textField: categoryTextField)
        self.topBottomBorder(textField: dateTextField)
        
        //Carreguem llista categories categoryTextField
        self.categoryPicker.tag = 0
        self.showCategoryPicker()
        
        //Carreguem llista locations locationTextField
        self.locationPicker.tag = 1
        self.showLocationPicker()
    }
    
    //Cridem funcions quan la vista ja ha aparegut
    override func viewDidAppear(_ animated: Bool) {
        //Com venim del Login (on haviem ocultat la navigatioBar) s'ha de mostrar navigationBar
        super.viewDidAppear(animated)
        self.navigationController?.navigationBar.isHidden = false
    }
    
    //Personalitza els borders de TextField
    func topBottomBorder(textField: UITextField) {
        let bottomBorder : CALayer = CALayer()
        let topBorder : CALayer = CALayer()
        bottomBorder.frame = CGRect(x: 0.0, y: textField.frame.size.height - 1, width: textField.frame.size.width, height: 1.0)
        topBorder.frame = CGRect(x: 0.0, y: 0.0, width: textField.frame.size.width, height: 1.0)
        bottomBorder.backgroundColor = (UIColor.gray).cgColor
        topBorder.backgroundColor = (UIColor.gray).cgColor
        textField.layer.addSublayer(bottomBorder)
        textField.layer.addSublayer(topBorder)
    }
    
    //Busquem events segons els criteris seleccionats
    func findEvents() {
        //Variables de cerca
        let categoryFinded = self.categoryTextField.text
        let locationFinded = self.locationTextField.text
        let dateFindedString = self.dateTextField.text
        
        //Inici consulta sobre taula Event
        let query = PFQuery(className: "Event")
        
        //Busqueda avançada si s'ha seleccionar algun camp
        if categoryFinded != "" {
            query.whereKey("category", equalTo: categoryFinded!)
        }
        if locationFinded != "" {
            query.whereKey("location", contains: locationFinded!)
        }
        if dateFindedString != "" {
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            let dateFinded = formatter.date(from: dateFindedString!)
            query.whereKey("date", greaterThanOrEqualTo: dateFinded!)
        }
        
        //Ordenem resultats segons Date
        query.addAscendingOrder("date")
        //Inciar activityIndicator
        self.startActivityIndicator()
        query.findObjectsInBackground { (objects, error) in

            if error == nil{
                if let objects = objects {
                    self.events.removeAll()
                    for object in objects {
                        if object["isPrivate"] as? Bool == false {
                            let eventId = object.objectId!
                            let title = object["title"] as! String
                            let description = object["description"] as! String
                            let date = object["date"] as! Date
                            let userId = object["userId"] as! String
                            let category = object["category"] as! String
                            let location = object["location"] as! String
                            let latitude = object["latitude"] as! Float
                            let longitude = object["longitude"] as! Float
                            //Event recuperat de BBDD - Falta la imatge
                            //Guardem en la posicio del array que el guardem
                            let eventPosition = self.events.count
                            //Creem objecte de tipus Event
                            let myEvent = Event(eventId: eventId,title: title, descrip: description, image: nil, userId:userId, date:date, category: category, location: location, latitude: latitude, longitude: longitude)
                            myEvent.eventId = eventId
                            //Afegim el event al array
                            self.events.append(myEvent)
                            
                            //Recuparem la Image i l'afegim a l'objecte
                            let image = object["image"] as! PFFile
                            image.getDataInBackground(block: { (data, error) in
                                if let data = data {
                                    let downloadImage = UIImage(data: data)
                                    self.events[eventPosition].image = downloadImage
                                }
                            })
                        }

                    }
                    self.stopActivityIndicator()
                }
            } else {
                print(error!.localizedDescription)
            }
            //Transició a la tableView Resultats per mostrar els events trobats
            self.performSegue(withIdentifier: "fromMainToResult", sender: self.events)
        }
    }
    
    //Configurem categoryPicker
    func showCategoryPicker() {
        categoryPicker.delegate = self
        categoryPicker.dataSource = self
        
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.done, target: self, action: #selector(saveCategoryPicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        let cancelButton = UIBarButtonItem(title: "Cancel", style: UIBarButtonItemStyle.plain, target: self, action: #selector(cancelCategoryPicker))
        toolBar.setItems([saveButton, space, cancelButton], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        categoryTextField.inputView = categoryPicker
        categoryTextField.inputAccessoryView = toolBar
    }
    
    //Retorn de valor al premer Save del categoryPicker
    func saveCategoryPicker() {
        categoryTextField.resignFirstResponder()
    }
    
    //Retorn sense valor al premer Cancel del cateogryPicker
    func cancelCategoryPicker() {
        categoryTextField.text = ""
        categoryTextField.resignFirstResponder()
    }
    
    //Configurem locationPicker
    func showLocationPicker() {
        locationPicker.delegate = self
        locationPicker.dataSource = self
        
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.done, target: self, action: #selector(saveLocationPicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        let cancelButton = UIBarButtonItem(title: "Cancel", style: UIBarButtonItemStyle.plain, target: self, action: #selector(cancelLocationPicker))
        toolBar.setItems([saveButton, space, cancelButton], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        locationTextField.inputView = locationPicker
        locationTextField.inputAccessoryView = toolBar
    }

    //Retorn de valor al premer Save del locationPicker
    func saveLocationPicker() {
        locationTextField.resignFirstResponder()
    }
    
    //Retorn sense valor al premer Cancel del locationPicker
    func cancelLocationPicker() {
        locationTextField.text = ""
        locationTextField.resignFirstResponder()
    }

    //Mostrem la llista d'elements dels pickers. Es mostra category o locations segons el TAG.
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        if pickerView.tag == 0 {
            return categories.categories.count
        } else {
            return locations.locations.count
        }
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        if pickerView.tag == 0 {
            categoryTextField.text = categories.categories[row]
        } else {
            locationTextField.text = locations.locations[row]
        }
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        if pickerView.tag == 0 {
            return categories.categories[row]
        } else {
            return locations.locations[row]
        }
    }
    
    
    //Mostrar Date seleccionada al dateTextView
    func datePickerValueChanged(sender: UIDatePicker) -> Date {
        
        let dateFormatter = DateFormatter()
        dateFormatter.dateStyle = .medium
        dateFormatter.timeStyle = .short
        dateTextField.text = dateFormatter.string(for: sender.date)!
        return sender.date
    }
    
    //Retorn al apretar Save del datePicker
    func saveDatePicker() {
        dateTextField.resignFirstResponder()
        
    }
    //Retorn sense valor al apretar Cancel del datePicker
    func cancelDatePicker() {
        dateTextField.text = ""
        dateTextField.resignFirstResponder()
    }
    
    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol toque a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
        
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }
    
    //Prepara la transició cap a una altra view en la que hi pasem elements, en aquest cas self.events
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromMainToResult" {
            if let resultViewController = segue.destination as? ResultTableViewController {
                resultViewController.events = self.events
            }
        }
    }
    
}

/**            **
 ** Extensions **
 **            **/

//Ocultarà el teclat al deseleccionar els textfield. Es necessari assignar los delegados
extension MainViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}

