//
//  MapViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 14/5/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import CoreLocation
import MapKit

class MapViewController: UIViewController, CLLocationManagerDelegate {

    /**           **
     ** Variables **
     **           **/
    
    var events : [Event]!
    let locationManager = CLLocationManager()
    
    /**          **
     **  Outlets **
     **          **/

    @IBOutlet weak var mapView: MKMapView!

    /**           **
     ** Functions **
     **           **/
    
    //Cridem funcions un cop la view esta carregada
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.mapView.delegate = self
        self.mapView.showsUserLocation = true
        //Funcio que pinta les locations en el mapa
        self.showEventsOnMap()
        
        self.locationManager.delegate = self
        self.locationManager.desiredAccuracy = kCLLocationAccuracyBest
        self.locationManager.requestWhenInUseAuthorization()
        self.locationManager.startUpdatingLocation()
    }
    
    //Funció que pinta les localitzacions dels events trobats al MAP
    func showEventsOnMap(){
        for event in events {
            let geoCoder = CLGeocoder()
            var annotations : [MKPointAnnotation] = []
            geoCoder.geocodeAddressString(event.location!, completionHandler: { (placemarks, error) in
                if error == nil {
                    //Recorrem array de placemarks
                    for placemark in placemarks! {
                        
                        let annotation = MKPointAnnotation()
                        annotation.title = event.title
                        annotation.subtitle = event.category
                    
                        annotation.coordinate = (placemark.location?.coordinate)!
                        annotations.append(annotation)
                    }
                    self.mapView.showAnnotations(annotations, animated: false)
                } else {
                    print("\(String(describing: error?.localizedDescription))")
                }
            })
        }
    }
    
    //Configurem la seccio que volem mostrar del mapa
    func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        
        let latDelta:CLLocationDegrees = 0.080
        let lonDelta:CLLocationDegrees = 0.080
        
        let span = MKCoordinateSpan(latitudeDelta: latDelta, longitudeDelta: lonDelta)
        //Posicionem el mapa sobre el centre de barcelona
        let coordinate = CLLocationCoordinate2D(latitude: 41.392101 , longitude: 2.162692)
        
        let region = MKCoordinateRegion(center: coordinate, span: span)
        
        self.mapView.setRegion(region, animated: true)
        
    }
 
}

/**            **
 ** Extensions **
 **            **/

extension MapViewController : MKMapViewDelegate {
    
    //Personalitzem com volem mostar el PIN (color, mida, icono...)
    func mapView(_ mapView: MKMapView, viewFor annotation: MKAnnotation) -> MKAnnotationView? {
        let identifier = "MyPin"
        if annotation.isKind(of: MKUserLocation.self){
            return nil
        }
        var annotationView : MKPinAnnotationView? = self.mapView.dequeueReusableAnnotationView(withIdentifier: identifier) as? MKPinAnnotationView
        if annotationView == nil {
            annotationView = MKPinAnnotationView(annotation: annotation, reuseIdentifier: identifier)
            annotationView?.canShowCallout = true
        }
        let imageView = UIImageView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        imageView.image = #imageLiteral(resourceName: "placeholder")
        imageView.backgroundColor = UIColor(red: 130/255, green: 204/255, blue: 243/255, alpha: 1.0)
        annotationView?.leftCalloutAccessoryView = imageView
        annotationView?.pinTintColor = UIColor(red: 130/255, green: 204/255, blue: 243/255, alpha: 1.0)
        
        return annotationView
    }
    
    
}
