//
//  NewEventViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 4/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse
import MapKit

class NewEventViewController: UIViewController, UINavigationControllerDelegate, UIImagePickerControllerDelegate, UIPickerViewDelegate, UIPickerViewDataSource {

    /**           **
     ** Variables **
     **           **/
    
    var activityIndicator : UIActivityIndicatorView!
    var categoryPicker = UIPickerView()
    var categories : Category = Category()
    var location : MKPlacemark?
    var image : UIImage?
    var eventTitle : String?
    var eventDescrip : String?
    var category : String?
    var date : String?
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var titleTextField: UITextField!
    @IBOutlet weak var descriptionTextView: UITextView!
    @IBOutlet weak var eventImageView: UIImageView!
    @IBOutlet weak var categoryTextView: UITextField!
    @IBOutlet weak var datePicker: UITextField!
    @IBOutlet weak var locationTextField: UITextField!
    @IBOutlet weak var descriptionTextField: UITextField!
    @IBOutlet weak var switchTextField: DesignableUITextField!
    @IBOutlet weak var eventSwitch: UISwitch!
    
    /**          **
     **  Actions **
     **          **/
    
    //Switch per definir event public o private
    @IBAction func eventSwitch(_ sender: UISwitch) {
        if self.eventSwitch.isOn == true {
            self.switchTextField.text = "Private"
        } else {
            self.switchTextField.text = "Public"
        }
    }
    
    //Transició cap a la view que ens deixa seleccionar una Location
    @IBAction func locationTextField(_ sender: UITextField) {
        self.performSegue(withIdentifier: "fromNewEventToLocation", sender: nil)
    }
    
    //Button de creació de l'event un cop omplerts tots els camps
    @IBAction func createButton(_ sender: UIBarButtonItem) {
        
        //Comprovem que tots els camps omplerts
        if infoCompleted() {
            self.startActivityIndicator()
            
            //Guardem un nou event a Parse
            let event = PFObject(className:"Event")
            //Assignem els camps
            event["userId"] = PFUser.current()?.objectId
            event["title"] = self.titleTextField.text
            event["description"] = self.descriptionTextView.text
            event["category"] = self.categoryTextView.text
            event["location"] = self.location!.title
            event["latitude"] = self.location!.coordinate.latitude
            event["longitude"] = self.location!.coordinate.longitude
            event["isPrivate"] = self.eventSwitch!.isOn
            
            //Date
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            event["date"] = formatter.date(from: self.datePicker.text!)
            //Image
            let imageData = UIImageJPEGRepresentation  (self.eventImageView.image!, 0.0)
            let image = PFFile(name:"image.jpg",data: imageData!)
            event["image"] = image
            
            //El guardem
            event.saveInBackground { (sucess, error) in
                self.stopActivityIndicator()
                if error == nil{
                    //Fem la transició a la view MAIN quan l'event s'ha creat
                    self.performSegue(withIdentifier: "fromNewEventToMain", sender: nil)
                    
                } else {
                    var errorMessage = "Error has ocurred during create event process"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "Create event error", message: errorMessage)
                }
                
            }
        }
    }
    
    //Carregar la imatge en la ImageView
    @IBAction func uploadButton(_ sender: UIButton) {
        let alertController = UIAlertController(title: "Select image", message: "", preferredStyle: .actionSheet)
        
        let libraryAction = UIAlertAction(title: "Library", style: .default) { (action) in
            self.loadFromLibrary()
        }
        let photoAction = UIAlertAction(title: "Photo", style: .default) { (action) in
            self.takePhoto()
        }
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler:nil)
        
        alertController.addAction(libraryAction)
        alertController.addAction(photoAction)
        alertController.addAction(cancelAction)
        
        self.present(alertController, animated: true, completion: nil)
    }

    //Carreguem la data en que es realitzara el event
    @IBAction func datePicker(_ sender: UITextField) {
        
        let datePickerView: UIDatePicker = UIDatePicker()
        datePickerView.datePickerMode = UIDatePickerMode.dateAndTime
        datePickerView.minimumDate = NSDate() as Date
        
        //Config button
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.plain, target: self, action: #selector(saveDatePicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        toolBar.setItems([saveButton, space], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        sender.inputView = datePickerView
        sender.inputAccessoryView = toolBar
        datePickerView.addTarget(self, action: #selector(UserProfileViewController.datePickerValueChanged), for: UIControlEvents.valueChanged)
        
    }

    /**           **
     ** Functions **
     **           **/
    
    //Executat quan la vista esta carregada
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //Cridar categoryPicker
        self.showCategoryPicker()
        
        //Border i placeholder textView
        if self.eventDescrip != "" {
            self.descriptionTextView.text = self.eventDescrip
        }
        self.descriptionTextView.placeholder = "Description"
        self.descriptionTextView.textAlignment = .left
        
        //Border TextField
        self.topBottomBorder(textField: self.titleTextField)
        self.topBottomBorder(textField: self.datePicker)
        self.topBottomBorder(textField: self.categoryTextView)
        self.topBottomBorder(textField: self.switchTextField)
        
        //Permet amagar el teclat fent tap a la pantalla
        self.hideKeyboardWhenTappingAround()
        
        //Mostar la location seleccionada
        self.showSelectedLocation()
        
        //descriptionTextView no editable
        self.descriptionTextField.isUserInteractionEnabled = false
    }
    
    //Carregar imartge des de library
    func loadFromLibrary(){
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .photoLibrary
        imagePicker.allowsEditing = false
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Carregar imatge des de foto
    func takePhoto() {
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .camera
        imagePicker.allowsEditing = false
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Guardem la imatge al imageView
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any]) {
        if let image = info[UIImagePickerControllerOriginalImage] as? UIImage {
            self.eventImageView.image = image
        }
        self.dismiss(animated: true, completion: nil)
    }
    
    //Ens recuperar els camps definits abans de que anemssim a la view Location
    func showSelectedLocation() {
        if location != nil {
            self.locationTextField.text = self.location!.title!
        }
        if image != nil {
            self.eventImageView.image = image
        }
        if eventTitle != nil {
            self.titleTextField.text = eventTitle
        }
        if eventDescrip != nil {
            self.descriptionTextView.text = eventDescrip
        }
        if category != nil {
            self.categoryTextView.text = category
        }
        if date != nil {
            self.datePicker.text = date
        }
    }
    
    //Configurem categoryPicker
    func showCategoryPicker() {
        categoryPicker.delegate = self
        categoryPicker.dataSource = self
        
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.plain, target: self, action: #selector(saveCategoryPicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        toolBar.setItems([saveButton, space], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        categoryTextView.inputView = categoryPicker
        categoryTextView.inputAccessoryView = toolBar
    }
    
    //Retorn al apretar Save del categoryPicker
    func saveCategoryPicker() {
        categoryTextView.resignFirstResponder()
    }
    
    //Configurem el categoryPicker, el numero d'elements que es mostraran
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return categories.categories.count
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        categoryTextView.text = categories.categories[row]
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return categories.categories[row]
    }
    
    //Configurem Date picker, data del event
    func datePickerValueChanged(sender: UIDatePicker) {
        
        let dateFormatter = DateFormatter()
        dateFormatter.dateStyle = .medium
        dateFormatter.timeStyle = .short
        datePicker.text = dateFormatter.string(for: sender.date)
    }
    
    //Retorn al apretar Save del datePicker
    func saveDatePicker() {
        datePicker.resignFirstResponder()
        
    }

    //Funcio per crear alertes d'error
    func createAlert(title: String, message: String){
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(okAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
   //Funcio per esborar el placeholder de TextView
    func textViewDidBeginEditing(_ descriptionTextView: UITextView) {
        if descriptionTextView.textColor == UIColor.lightGray {
            descriptionTextView.text = nil
            descriptionTextView.textColor = UIColor.black
        }
    }
   
    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol toque a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }
    
    //Funcio per comprobar que introduim totes les dades del formulari
    func infoCompleted() -> Bool {
        var infoCompleted = true
        
        if self.titleTextField.text == "" || self.descriptionTextView.text == "" || self.categoryTextView.text == "" || self.locationTextField.text == "" || self.datePicker.text == "" || eventImageView.image == nil{
            infoCompleted = false
            self.createAlert(title: "Verificar los datos",message: "Rellenar todos los datos solicitados")
            
        }
        return infoCompleted
    }
    
    //Personalitza els borders de TextField
    func topBottomBorder(textField: UITextField) {
        let bottomBorder : CALayer = CALayer()
        let topBorder : CALayer = CALayer()
        bottomBorder.frame = CGRect(x: 0.0, y: textField.frame.size.height - 1, width: textField.frame.size.width, height: 1.0)
        if textField.text != "Public" {
            topBorder.frame = CGRect(x: 0.0, y: 0.0, width: textField.frame.size.width, height: 1.0)
        }
        bottomBorder.backgroundColor = (UIColor.gray).cgColor
        topBorder.backgroundColor = (UIColor.gray).cgColor
        textField.layer.addSublayer(bottomBorder)
        textField.layer.addSublayer(topBorder)
    }
    
    //Preparem la transicio a Location guardant els camps ja seleccionats
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromNewEventToLocation" {
            if let locationViewController = segue.destination as? LocationViewController {
                if self.eventImageView.image != nil{
                    locationViewController.image = self.eventImageView.image
                }
                if self.titleTextField.text != nil{
                    locationViewController.eventTitle = self.titleTextField.text
                }
                if self.descriptionTextView.text != nil{
                    locationViewController.eventDescrip = self.descriptionTextView.text
                }
                if self.categoryTextView.text != nil{
                    locationViewController.category = self.categoryTextView.text
                }
                if self.datePicker.text != nil{
                    locationViewController.date = self.datePicker.text
                }
            }
        }
    }
    
}

/**            **
 ** Extensions **
 **            **/

//Ocultarà el teclat al deseleccionar els textfield. Es necessari assignar los delegados
extension NewEventViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}

//Ocultarà el teclat al fer un tap fora dels textfield. Es necessari assignar els texfields al delegate de la view
extension NewEventViewController: UITextViewDelegate {
    func textViewShouldEndEditing(_ textView: UITextView) -> Bool {
        textView.resignFirstResponder()
        return true
    }
}


