//
//  ResultTableViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 5/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class ResultTableViewController: UITableViewController {

    /**           **
     ** Variables **
     **           **/
    
    var events : [Event]!
    
    /**           **
     ** Functions **
     **           **/
    
    //Cridem funcions un cop la view esta carregada
    override func viewDidLoad() {
        super.viewDidLoad()
      
        //Refresh de la taula al tirar cap avall
        self.refreshControl = UIRefreshControl()
        self.refreshControl?.attributedTitle = NSAttributedString(string: "")
        self.refreshControl?.addTarget(self, action: #selector(ResultTableViewController.reloadData), for: .valueChanged)
        
        //Item Button Map
        self.navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Map",style: .done, target: self, action: #selector(mapTapped))
    }
    
    //Funció per fer un refresh de les dades la taula
    func reloadData(){
        self.tableView.reloadData()
        self.refreshControl?.endRefreshing()
    }
    
    //Accio al apretar itemButtonMap
    func mapTapped() {
        //Transició cap al MAP
         self.performSegue(withIdentifier: "fromResultToMap", sender: self.events)
    }
    
    //Configuració de la taula i carrega dels events a mostrar
    override func numberOfSections(in tableView: UITableView) -> Int {
        //Numero de seccions
        return 1
     }
     
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        //Numero de files
        return self.events!.count
     }
     
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        //Valors per cada cel·la
        let cell = tableView.dequeueReusableCell(withIdentifier: "resultCell", for: indexPath) as! ResultTableViewCell
        
        let event = self.events[indexPath.row]
        cell.titleLabel.text = event.title
        cell.eventImageView?.image = event.image
        let formatter = DateFormatter()
        formatter.dateStyle = .medium
        formatter.timeStyle = .short
        cell.dateLabel.text = formatter.string(from: event.date)
        cell.locationLabel.text = event.location
        
        return cell
     }
    
    //Preparem la transicó cap a MAP o al seleccionar una CELL
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromResultToMap" {
            if let mapViewController = segue.destination as? MapViewController {
                //Passem tot el array d'events trobats
                mapViewController.events = self.events
            }
        }
        if segue.identifier == "fromResultToEventDetail" {
            if let eventDetailController = segue.destination as? EventDetailViewController {
                if let indexPath = self.tableView.indexPathForSelectedRow {
                    //Passem el event de la cell seleccionada
                    eventDetailController.event = self.events[indexPath.row]
                }
            }
        }
    }
    
}
