//
//  LoginViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 1/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class LoginViewController: UIViewController {

    /**           **
     ** Variables **
     **           **/
    
    var activityIndicator : UIActivityIndicatorView!
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var userTextField: UITextField!
    @IBOutlet weak var passwordTextField: UITextField!
    
    /**          **
     **  Actions **
     **          **/
    
    //Recuperacio password - Es mostren les opcions en un alertController
    @IBAction func recoveryPasswordButton(_ sender: UIButton) {
        let alertController = UIAlertController(title: "Reset password", message: "Enter your email address", preferredStyle: .alert)
        alertController.addTextField { (textfield) in
            textfield.placeholder = "Email"
            textfield.keyboardType = UIKeyboardType.emailAddress
        }
        
        let okAlert = UIAlertAction(title: "Reset password", style: .default) { (action) in
            let email = alertController.textFields![0] as UITextField
            
            PFUser.requestPasswordResetForEmail(inBackground: email.text!,block: { (sucess, error) in
                if (!(error != nil)){
                    self.createAlert(title: "Reset password", message: "Check \(email.text!) email inbox and follow the provided instructions")
                } else {
                    var errorMessage = "Sorry, error has occurred"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "Error has ocurred during reset password process", message: errorMessage)
                }
            })
        }
        
        let cancelAction = UIAlertAction(title: "Cancel",style: .cancel, handler: nil)
        
        alertController.addAction(okAlert)
        alertController.addAction(cancelAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Login
    @IBAction func loginButton(_ sender: UIButton) {
        if infoCompleted(){
            
            //Inciar activityIndicator
            self.startActivityIndicator()
            
            //Login usuari
            PFUser.logInWithUsername(inBackground: self.userTextField.text!, password: self.passwordTextField.text!,block: { (user, error) in
                
                //Stop activityIndicator
                self.stopActivityIndicator()
                
                if (!(error != nil)){
                    //Transició a la pantalla Main quan login OK
                    self.performSegue(withIdentifier: "fromLoginToMain", sender: nil)
                } else {
                    var errorMessage = "Error! Try again, please"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "Login Error", message: errorMessage)
                }
            })
        }
    }
    
    //Ens mou a la pantalla NewUser
    @IBAction func newUserButton(_ sender: UIButton) {
        
        //Transició a la pantalla NewUser
        self.performSegue(withIdentifier: "fromLoginToNewUser", sender: nil)
    }

    
    /**           **
     ** Functions **
     **           **/
    
    override func viewDidLoad() {
        super.viewDidLoad()
        //Permet amagar el teclat fent tap a la pantalla
        self.hideKeyboardWhenTappingAround()
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        //Ocultar navigation bar ja que es la pantalla de Login
        self.navigationController?.navigationBar.isHidden = true
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        //Els usuaris amb sessió valida no han de tornar-se a logar
        if PFUser.current() != nil {
            //Fa la transició al Main quan hi ha usuari logat
            self.performSegue(withIdentifier: "fromLoginToMain", sender: nil)
        }
    }
    
    //Controla la obigació de introduir les dades en el formulari de login
    func infoCompleted() -> Bool {
        var infoCompleted = true
        
        if self.userTextField.text == "" || self.passwordTextField.text == "" {
            infoCompleted = false

            let alertController = UIAlertController(title: "Authentication failed", message: "Invalid username and password. Try again.", preferredStyle: .alert)
            let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
            alertController.addAction(okAction)
            self.present(alertController, animated: true, completion: nil)
        }
        return infoCompleted
    }
    
    //Funcio per crear alertes d'error
    func createAlert(title: String, message: String){
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(okAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol tap a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }
}

/**            **
 ** Extensions **
 **            **/

//Ocultarà el teclat al fer un tap fora dels textfield. Es necessari assignar els texfields al delegate de la view
extension LoginViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}

