//
//  UserEventsInfoTableViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 16/5/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import Parse

class UserEventsInfoViewController: UITableViewController {

    //Outlets
    @IBOutlet weak var menuButton: UIBarButtonItem!
    
    
    //Variables
    //Declarem activityIndicator
    var activityIndicator : UIActivityIndicatorView!
    //Declarem 2 arrays de Event
    var eventsUser : [Event] = []
    var eventsJoin : [Event] = []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.loadEventsUser()
        self.loadEventsJoin()
        
        self.refreshControl = UIRefreshControl()
        self.refreshControl?.attributedTitle = NSAttributedString(string: "")
        self.refreshControl?.addTarget(self, action: #selector(UserEventsInfoViewController.reloadData), for: .valueChanged)
        
        //buttonMenu
        if self.revealViewController() != nil {
            self.menuButton.target = self.revealViewController()
            self.menuButton.action = #selector(SWRevealViewController.revealToggle(_:))
            self.view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
        }
    }

    func reloadData(){
        self.tableView.reloadData()
        self.refreshControl?.endRefreshing()
    }
    
    //Functions
    func loadEventsUser() {
        self.eventsUser.removeAll()
        let query = PFQuery(className: "Event")
        query.whereKey("userId", equalTo: PFUser.current()!.objectId!)
        query.addAscendingOrder("date")
        query.findObjectsInBackground { (objects, error) in
            if error == nil {
                if let objects = objects {
                    for object in objects {
                        //Tots els elements
                        let eventId = object.objectId!
                        let title = object["title"] as! String
                        let description = object["description"] as! String
                        let image = object["image"] as! PFFile
                        let userId = object["userId"] as! String
                        let date = object["date"] as! Date
                        let category = object["category"] as! String
                        let location = object["location"] as! String
                        let latitude = object["latitude"] as! Float
                        let longitude = object["longitude"] as! Float
                        
                        //Posicio en array events
                        let eventPosition = self.eventsUser.count
                        //Inicialitzem l'objecte Event
                        let myEvent = Event(eventId: eventId, title: title, descrip: description, image: nil, userId: userId, date: date, category: category, location: location, latitude: latitude, longitude: longitude)
                        //Recuparem la Image i l'afegim a l'objecte
                        image.getDataInBackground(block: { (data, error) in
                            if let data = data {
                                let downloadImage = UIImage(data: data)
                                self.eventsUser[eventPosition].image = downloadImage
                            }
                        })
                        //Afegim l'event al array
                        self.eventsUser.append(myEvent)
                        self.tableView.reloadData()
                    }
                }
            } else{
                print(error!.localizedDescription)
            }
        }
    }
    
    func loadEventsJoin() {
        self.eventsJoin.removeAll()
        let query = PFQuery(className: "JoinEvent")
        query.whereKey("userId", equalTo: PFUser.current()!.objectId!)
        query.addAscendingOrder("date")
        query.findObjectsInBackground { (objects, error) in
            if error == nil {
                if let objects = objects {
                    for object in objects {
                        let eventId = object["eventId"] as! String
                        let event = PFQuery(className: "Event")
                        event.whereKey("objectId", equalTo: eventId)
                        event.findObjectsInBackground(block: { (eventsReturned, error) in
                          
                            if error == nil {
                                if let eventsReturned = eventsReturned {
                                    for eventReturned in eventsReturned {
                                        //Tots els elements
                                        let eventId = eventReturned.objectId!
                                        let title = eventReturned["title"] as! String
                                        let description = eventReturned["description"] as! String
                                        let image = eventReturned["image"] as! PFFile
                                        let userId = eventReturned["userId"] as! String
                                        let date = eventReturned["date"] as! Date
                                        let category = eventReturned["category"] as! String
                                        let location = eventReturned["location"] as! String
                                        let latitude = eventReturned["latitude"] as! Float
                                        let longitude = eventReturned["longitude"] as! Float
                                        //Posicio en array events
                                        let eventPosition = self.eventsJoin.count
                                        
                                        //Inicialitzem l'objecte Event
                                        let myEvent = Event(eventId: eventId, title: title, descrip: description, image: nil, userId: userId, date: date, category: category, location: location, latitude: latitude, longitude: longitude)
                                        
                                        //Recuparem la Image i l'afegim a l'objecte
                                        image.getDataInBackground(block: { (data, error) in
                                            if let data = data {
                                                let downloadImage = UIImage(data: data)
                                                self.eventsJoin[eventPosition].image = downloadImage
                                            }
                                        })
                                        //Afegim l'event al array
                                        self.eventsJoin.append(myEvent)
                                        self.tableView.reloadData()
                                    }
                                }
                            } else {
                                print(error!.localizedDescription)
                            }
                        })
                    }
                    
                }
            } else{
                print(error!.localizedDescription)
            }
        }
    }

    // MARK: - Table view data source
    override func numberOfSections(in tableView: UITableView) -> Int {
        return 2
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        
        switch section {
        case 0:
            return self.eventsJoin.count
        case 1:

            return self.eventsUser.count
        default:
            return 0
        }
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "eventUser", for: indexPath) as! EventUserViewCell

        switch indexPath.section {
        case 0:
            cell.eventUserImageView.image = self.eventsJoin[indexPath.row].image
            cell.titleEventUserLabel.text = self.eventsJoin[indexPath.row].title
            cell.locationEventUserLabel.text = self.eventsJoin[indexPath.row].location
            
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            cell.dateEventUserLabel.text = formatter.string(from:self.eventsJoin[indexPath.row].date)
            
        case 1:
            cell.eventUserImageView.image = self.eventsUser[indexPath.row].image
            cell.titleEventUserLabel.text = self.eventsUser[indexPath.row].title
            cell.locationEventUserLabel.text = self.eventsUser[indexPath.row].location
            
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            cell.dateEventUserLabel.text = formatter.string(from:self.eventsUser[indexPath.row].date)
        default:
            break
        }
        return cell
    }
 
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        var title = ""
        switch section {
        case 0:
            title = "JOINED"
        case 1:
            title = "CREATED"
        default:
            break
        }
        return title
    }
    
    //Esborrar o join a un esdeveniment
    override func tableView(_ tableView: UITableView, editActionsForRowAt indexPath: IndexPath) -> [UITableViewRowAction]? {
        
        switch indexPath.section {
        case 0:
            let notJoin = UITableViewRowAction(style: .normal, title: "Not Join", handler: { (action, indexPath) in
                let eventId = self.eventsJoin[indexPath.row].eventId
                let query = PFQuery(className: "JoinEvent")
                query.whereKey("eventId", equalTo: eventId!)
                query.findObjectsInBackground(block: { (objects, error) in
                    if error == nil {
                        for object in objects! {
                            object.deleteInBackground(block: { (success, error) in
                                if error == nil {
                                    print("Ya no sigues el evento")
                                    self.eventsJoin.remove(at: indexPath.row)
                                    self.tableView.reloadData()
                                } else {
                                    print(error!.localizedDescription)
                                }
                            })
                        }
                    } else {
                        print(error!.localizedDescription)
                    }
                })
                
            })
            notJoin.backgroundColor = #colorLiteral(red: 0.7126088738, green: 0.0992994532, blue: 0.01260930859, alpha: 1)
            return [notJoin]
            
        case 1:
            let delete = UITableViewRowAction(style: .normal, title: "Delete") { (action, indexPath) in
                let eventIdDelete = self.eventsUser[indexPath.row].eventId
                let queryDelete = PFQuery(className: "Event")
                queryDelete.whereKey("objectId", equalTo: eventIdDelete!)
                queryDelete.findObjectsInBackground(block: { (objects, error) in
                    if error == nil {
                        for object in objects! {
                            object.deleteInBackground(block: { (success, error) in
                                if error == nil{
                                    print("Evento borrado correctamente")
                                    self.eventsUser.remove(at: indexPath.row)
                                    self.tableView.reloadData()
                                    for eventJoin in self.eventsJoin {
                                        if eventJoin.eventId == eventIdDelete {
                                            let index = self.eventsJoin.index(of: eventJoin)
                                            self.eventsJoin.remove(at: index!)
                                            self.tableView.reloadData()
                                        }
                                    }

                                } else {
                                    print(error!.localizedDescription)
                                }
                            })
                        }
                    } else {
                        print(error!.localizedDescription)
                    }
                })
            }
            delete.backgroundColor = #colorLiteral(red: 0.7126088738, green: 0.0992994532, blue: 0.01260930859, alpha: 1)
            return [delete]
            
        default:
            return []
        }
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromUserEventsToDetail" {
            if let userEventDetailController = segue.destination as? UserEventsInfoDetailViewController {
                let indexPath = self.tableView.indexPathForSelectedRow
                if indexPath?.section  == 0{
                    userEventDetailController.event = self.eventsJoin[(indexPath?.row)!]
                } else {
                    userEventDetailController.event = self.eventsUser[(indexPath?.row)!]
                }
            }
        }
    }
}

