//
//  UsersViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 7/6/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import Parse

class UsersViewController: UIViewController {

    //Variables
    var event : Event!
    var users : [User] = []
    var sharedUsers : [String] = []
    var activityIndicator : UIActivityIndicatorView!
    
    //Outlet
    @IBOutlet weak var titleEventLabel: UILabel!
    @IBOutlet weak var tableView: UITableView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        //imageview bordes rodons
        
        
        //Assignem el titol del event al label
        self.titleEventLabel.text = self.event.title
        
        //Carreguem els users
        self.sharedUser()
        self.loadUsers()
        
        
        //Refreix info taula
        self.tableView.refreshControl = UIRefreshControl()
        self.tableView.refreshControl?.attributedTitle = NSAttributedString(string: "")
        self.tableView.refreshControl?.addTarget(self, action: #selector(UserEventsInfoViewController.reloadData), for: .valueChanged)
        
    }
    
    func reloadData(){
        self.tableView.reloadData()
        self.tableView.refreshControl?.endRefreshing()
    }
    
    
    func sharedUser(){
        let query = PFQuery(className: "ShareEvent")
        query.findObjectsInBackground { (objects, error) in
            if error == nil {
                if let objects = objects {
                    for object in objects {
                        let userId = object["userId"] as! String
                        self.sharedUsers.append(userId)
                    }
                }
            } else {
                print(error!.localizedDescription)
            }
        }
    }


    
    func loadUsers() {
        let query = PFUser.query()
        query?.addAscendingOrder("name")
        query?.findObjectsInBackground(block: { (objects, error) in
            if error == nil {
                self.users.removeAll()
                for object in objects! {
                    if let user = object as? PFUser {
                        if user.objectId != PFUser.current()?.objectId {
                            let userId = user.objectId!
                            let name = user["name"] as! String
                            let surname = user["surname"] as! String
                            let username = user.username!
                            let email = "parse@nolo.recupera"
                            let birthday = user["birthday"] as! Date
                            let image = user["image"] as! PFFile
                            
                            //Posicio en array events
                            let userPosition = self.users.count
                            //Inicialitzem l'objecte Event
                            let myUser = User(userId: userId, name: name, surname: surname, username: username, email: email, birthday: birthday, image: nil)
                            //Recuparem la Image i l'afegim a l'objecte
                            image.getDataInBackground(block: { (data, error) in
                                if let data = data {
                                    let downloadImage = UIImage(data: data)
                                    self.users[userPosition].image = downloadImage
                                }
                            })
                            //Afegim l'event al array
                            self.users.append(myUser)
                            print(myUser.name)

                        }
                    }
                }
                self.tableView.reloadData()
                
            } else {
                print(error!.localizedDescription)
            }
        })
    }
    
    //Funcio per crear alertes d'error
    func createAlert(title: String, message: String){
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(okAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol toque a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }
    
    
}

extension UsersViewController : UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.users.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "userCell", for: indexPath) as! UsersViewCell
        
        cell.imageUser.image = self.users[indexPath.row].image
        cell.imageUser.layer.cornerRadius = 25
        cell.imageUser.layer.masksToBounds = true
        cell.nameLabel.text = self.users[indexPath.row].name
        cell.surnameLabel.text = self.users[indexPath.row].surname
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        self.startActivityIndicator()
        let user = self.users[indexPath.row]
        
        let query = PFObject(className: "ShareEvent")
        query["eventId"] = self.event.eventId
        query["userId"] = user.userId
        query["currentUserId"] = PFUser.current()?.objectId
        
        query.saveInBackground { (success, error) in
            self.stopActivityIndicator()
            if error != nil {
                print(error!.localizedDescription)
            } else {
                self.createAlert(title: "Event Shared", message: "The event \(self.event.title!) has been shared with \(user.name!) \(user.surname!)")
            }
        }
        
        
    }
}

extension UsersViewController : UITableViewDelegate {
    
}
