//
//  NewUserViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 1/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class NewUserViewController: UIViewController, UINavigationControllerDelegate, UIImagePickerControllerDelegate {
    
    
    /**           **
     ** Variables **
     **           **/
    
    var activityIndicator : UIActivityIndicatorView!
    
    /**          **
     **  Outlets **
     **          **/
    
    @IBOutlet weak var newNameTextField: UITextField!
    @IBOutlet weak var newSurnameTextField: UITextField!
    @IBOutlet weak var newUserTextField: UITextField!
    @IBOutlet weak var newPasswordTextField: UITextField!
    @IBOutlet weak var newEmailTextField: UITextField!
    @IBOutlet weak var newImageView: UIImageView!
    @IBOutlet weak var birthdayTextField: UITextField!
    
    /**          **
     **  Actions **
     **          **/
    
    //Datepicker per capturar la data de naixement
    @IBAction func birthdayTextFieldEditing(_ sender: UITextField) {
        
        //Inicialitzar datePicker
        let datePickerView: UIDatePicker = UIDatePicker()
        datePickerView.datePickerMode = UIDatePickerMode.date
        datePickerView.maximumDate = NSDate() as Date
        
        //Configurar buttons
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Save", style: UIBarButtonItemStyle.plain, target: self, action: #selector(savePicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        toolBar.setItems([saveButton, space], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        //Configurar datePicker
        sender.inputView = datePickerView
        sender.inputAccessoryView = toolBar
        datePickerView.addTarget(self, action: #selector(UserProfileViewController.datePickerValueChanged), for: UIControlEvents.valueChanged)
    }

    //Carregar la imatge
    @IBAction func newUploadPhotoButton(_ sender: UIButton) {
        let alertController = UIAlertController(title: "Select image", message: "", preferredStyle: .actionSheet)
        
        let libraryAction = UIAlertAction(title: "Library", style: .default) { (action) in
            self.loadFromLibrary()
        }
        let photoAction = UIAlertAction(title: "Photo", style: .default) { (action) in
            self.takePhoto()
        }
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler:nil)
        
        alertController.addAction(libraryAction)
        alertController.addAction(photoAction)
        alertController.addAction(cancelAction)
        
        self.present(alertController, animated: true, completion: nil)
    }

    //Crear l'usuari a parse amb les dades introduides
    @IBAction func signUpButton(_ sender: UIButton) {
        
        //Comprovem que totes les dades estiguin introduides
        if infoCompleted() {
            
            //Inciar activityIndicator
            self.startActivityIndicator()
            
            //Pasem a registar l'usuari
            let user = PFUser()
            user["name"] = self.newNameTextField.text
            user["surname"] = self.newSurnameTextField.text
            user.username = self.newUserTextField.text
            user.password = self.newPasswordTextField.text
            user.email = self.newEmailTextField.text
            
            let formatter = DateFormatter()
            formatter.dateFormat = "dd MMM yyyy"
            user["birthday"] = formatter.date(from: self.birthdayTextField.text!)
            
            //Imatge
            let imageData = UIImageJPEGRepresentation(self.newImageView.image!, 0.0)
            let image = PFFile(name:"image.jpg",data: imageData!)
            user["image"] = image
            
            
            //Registar a Parse l'usuari
            user.signUpInBackground(block: { (sucess, error) in
                
                //Stop activityIndicator
                self.stopActivityIndicator()
                
                if (!(error != nil)){
                    //Transició cap a la pantalla de Login
                    self.performSegue(withIdentifier: "fromNewUserToLogin", sender: nil)
                    
                } else {
                    var errorMessage = "Error! Try again, please"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "SignUp Error", message: errorMessage)
                }
            })
        }
    }
    
    //Acció del button cancelar
    @IBAction func cancelButton(_ sender: UIBarButtonItem) {
        
        //Transició cap al Login al cancelar
        self.performSegue(withIdentifier: "fromNewUserToLogin", sender: nil)
        
    }

    /**           **
     ** Functions **
     **           **/
    
    //Crides un cop carregada la view
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //Configurem imatge rodona
        self.newImageView?.layer.cornerRadius = 70
        self.newImageView?.layer.masksToBounds = true
        
        //Posem bordes als TextField
        self.topBottomBorder(textField: newNameTextField)
        self.topBottomBorder(textField: newUserTextField)
        self.topBottomBorder(textField: newEmailTextField)
        self.topBottomBorder(textField: birthdayTextField)
        
        //Permet amagar el teclat fent tap a la pantalla
        self.hideKeyboardWhenTappingAround()
    }
    
    //Guardem valor seleccionat al datePicker
    func datePickerValueChanged(sender: UIDatePicker) -> Date {
        
        let dateFormatter = DateFormatter()
        dateFormatter.dateStyle = .medium
        dateFormatter.timeStyle = .none
        birthdayTextField.text = dateFormatter.string(for: sender.date)
        return sender.date
    }
    
    //Retorn al apretar Save del datePicker
    func savePicker() {
        birthdayTextField.resignFirstResponder()

    }
    
    //Carregar de la imatge des de library
    func loadFromLibrary(){
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .photoLibrary
        imagePicker.allowsEditing = true
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Carregar de la imatge des de foto
    func takePhoto() {
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .camera
        imagePicker.allowsEditing = true
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Recuperem la imatge per mostrar-la en pantalla
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any]) {
        if let image = info[UIImagePickerControllerOriginalImage] as? UIImage {
            self.newImageView.image = image
        }
        self.dismiss(animated: true, completion: nil)
    }

    //Funcio per comprobar que totes les dades del formulari estan introduides
    func infoCompleted() -> Bool {
        var infoCompleted = true
        
        if self.newNameTextField.text == "" || self.newSurnameTextField.text == "" || self.newUserTextField.text == "" || self.newPasswordTextField.text == "" || self.newEmailTextField.text == "" || self.birthdayTextField.text == "" || newImageView.image == nil{
            infoCompleted = false
            self.createAlert(title: "Check fields",message: "Please, fill in all fields")
            
        }
        return infoCompleted
    }
    
    //Funcio per crear alertes d'error
    func createAlert(title: String, message: String){
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(okAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol toque a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }

    //Personalitza els borders de TextField
    func topBottomBorder(textField: UITextField) {
        let bottomBorder : CALayer = CALayer()
        let topBorder : CALayer = CALayer()
        bottomBorder.frame = CGRect(x: 0.0, y: textField.frame.size.height - 1, width: textField.frame.size.width, height: 1.0)
        if textField.placeholder != "Birthday" {
            topBorder.frame = CGRect(x: 0.0, y: 0.0, width: textField.frame.size.width, height: 1.0)
        }
        bottomBorder.backgroundColor = (UIColor.gray).cgColor
        topBorder.backgroundColor = (UIColor.gray).cgColor
        textField.layer.addSublayer(bottomBorder)
        textField.layer.addSublayer(topBorder)
    }

}

/**            **
 ** Extensions **
 **            **/

//Ocultarà el teclat al fer un tap fora dels textfield. Es necessari assignar els texfields al delegate de la view
extension NewUserViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}
