//
//  UserProfileViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 4/5/17.
//  Copyright © 2017 HaoBao. All rights reserved.
//

import UIKit
import Parse

class UserProfileViewController: UIViewController, UINavigationControllerDelegate, UIImagePickerControllerDelegate {

    
    //Variables
    //Declarem activityIndicator
    var activityIndicator : UIActivityIndicatorView!
    
    //Outlets
    @IBOutlet weak var profileImageView: UIImageView!
    @IBOutlet weak var nameLabel: UILabel!
    @IBOutlet weak var surnameLabel: UILabel!
    @IBOutlet weak var nameTextField: UITextField!
    @IBOutlet weak var surnameTextField: UITextField!
    @IBOutlet weak var usernameTextField: UITextField!
    @IBOutlet weak var emailTextField: UITextField!
    @IBOutlet weak var birthdayTextField: UITextField!
    @IBOutlet weak var passwordTextField: UITextField!
    @IBOutlet weak var menuButton: UIBarButtonItem!


    
    
    //Actions
    @IBAction func saveButton(_ sender: UIBarButtonItem) {
        
        //Comprovem que les dades estiguin introduides
        if infoCompleted() {
            
            //Inciar activityIndicator
            self.startActivityIndicator()
            
            //Pasem a registar l'usuari
            let user = PFUser.current()!
            user["name"] = self.nameTextField.text
            user["surname"] = self.surnameTextField.text
            user.username = self.usernameTextField.text
            user.email = self.emailTextField.text
            
            let formatter = DateFormatter()
            formatter.dateFormat = "dd MMM yyyy"
            user["birthday"] = formatter.date(from: self.birthdayTextField.text!)
            
            //imatge
            let imageData = UIImageJPEGRepresentation(self.profileImageView.image!, 0.8)
            let image = PFFile(name:"image.jpg",data: imageData!)
            user["image"] = image
            
            //Registar a Parse l'usuari
            user.saveInBackground(block: { (success, error) in
                
                //Stop activityIndicator
                self.stopActivityIndicator()
                
                if (!(error != nil)){
                    self.loadUserProfile()
                    print("Datos actualizados correctamente")
                    self.createAlert(title: "Congratulations!", message: "Information has been updated successfully")
                    
                } else {
                    var errorMessage = "Intentalo de nuevo, ha habido un error en los datos"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "Error de registro", message: errorMessage)
                }
                
            })
        }
    }
    
    @IBAction func logOffButton(_ sender: UIButton) {
        self.startActivityIndicator()
        PFUser.logOutInBackground { (error) in
            self.stopActivityIndicator()
            if (error != nil) {
                print(error!)
            }else {
                print("LOG_OFF")
            }
        }
        //Hacer la transicion a la pantalla de login cuando registro OK
        self.performSegue(withIdentifier: "fromUserProfileToLogin", sender: nil)
    }
    
    //Datepicker
    @IBAction func birthdayFieldEditing(sender: UITextField) {
        
        let datePickerView: UIDatePicker = UIDatePicker()
        datePickerView.datePickerMode = UIDatePickerMode.date
        datePickerView.maximumDate = NSDate() as Date
        
        //Config button
        let toolBar: UIToolbar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.tintColor = UIColor.blue
        toolBar.sizeToFit()
        
        let saveButton = UIBarButtonItem(title: "Done", style: UIBarButtonItemStyle.plain, target: self, action: #selector(savePicker))
        let space = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        toolBar.setItems([saveButton, space], animated: false)
        toolBar.isUserInteractionEnabled = true
        
        sender.inputView = datePickerView
        sender.inputAccessoryView = toolBar
        datePickerView.addTarget(self, action: #selector(UserProfileViewController.datePickerValueChanged), for: UIControlEvents.valueChanged)
    }
    
    func datePickerValueChanged(sender: UIDatePicker) {
        
        let dateFormatter = DateFormatter()
        dateFormatter.dateStyle = .medium
        dateFormatter.timeStyle = .none
        birthdayTextField.text = dateFormatter.string(for: sender.date)
    }
    
    
    //Retorn al apretar Save del datePicker
    func savePicker() {
        birthdayTextField.resignFirstResponder()
        
    }
    
    
    @IBAction func passwordTextField(_ sender: UITextField) {
        let alertController = UIAlertController(title: "Reset password", message: "Enter your email address", preferredStyle: .alert)
        alertController.addTextField { (textfield) in
            textfield.placeholder = "Email"
            textfield.keyboardType = UIKeyboardType.emailAddress
        }
        
        let okAlert = UIAlertAction(title: "Reset password", style: .default) { (action) in
            let email = alertController.textFields![0] as UITextField
            
            PFUser.requestPasswordResetForEmail(inBackground: email.text!,block: { (sucess, error) in
                if (!(error != nil)){
                    self.createAlert(title: "Reset password", message: "Check \(email.text!) email inbox and follow the provided instructions")
                } else {
                    var errorMessage = "Sorry, error has occurred"
                    if let parseError = error?.localizedDescription {
                        errorMessage = parseError
                    }
                    self.createAlert(title: "Error has ocurred during reset password process", message: errorMessage)
                }
            })
        }
        
        let cancelAction = UIAlertAction(title: "Cancel",style: .cancel, handler: nil)
        
        alertController.addAction(okAlert)
        alertController.addAction(cancelAction)
        self.present(alertController, animated: true, completion: nil)
        
        

    }
    
    @IBAction func changePhoto(_ sender: UIButton) {
        
        let alertController = UIAlertController(title: "Select image", message: "", preferredStyle: .actionSheet)
        
        let libraryAction = UIAlertAction(title: "Library", style: .default) { (action) in
            self.loadFromLibrary()
        }
        let photoAction = UIAlertAction(title: "Photo", style: .default) { (action) in
            self.takePhoto()
        }
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler:nil)
        
        alertController.addAction(libraryAction)
        alertController.addAction(photoAction)
        alertController.addAction(cancelAction)
        
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Carregar des de library
    func loadFromLibrary(){
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .photoLibrary
        imagePicker.allowsEditing = true
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Carregar des de foto
    func takePhoto() {
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = self
        imagePicker.sourceType = .camera
        imagePicker.allowsEditing = true
        self.present(imagePicker, animated: true, completion: nil)
    }
    
    //Recuperem imatge
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any]) {
        if let image = info[UIImagePickerControllerOriginalImage] as? UIImage {
            self.profileImageView.image = image
        }
        self.dismiss(animated: true, completion: nil)
    }

    //Functions
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //Carreguem dades de perfil
        self.loadUserProfile()
        
        //image
        self.profileImageView?.layer.cornerRadius = 70
        self.profileImageView?.layer.masksToBounds = true
        
        //Permet amagar el teclat fent tap a la pantalla
        self.hideKeyboardWhenTappingAround()
        
        //topBottom borders TextField
        self.topBottomBorder(textField: self.nameTextField)
        self.topBottomBorder(textField: self.usernameTextField)
        self.topBottomBorder(textField: self.emailTextField)
        self.topBottomBorder(textField: self.birthdayTextField)
    
        //buttonMenu
        if self.revealViewController() != nil {
            self.menuButton.target = self.revealViewController()
            self.menuButton.action = #selector(SWRevealViewController.revealToggle(_:))
            self.view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
        }
    }

    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        self.navigationController?.navigationBar.isHidden = false
    }
    

    //Personalitza els borders de TextField
    func topBottomBorder(textField: UITextField) {
        let bottomBorder : CALayer = CALayer()
        let topBorder : CALayer = CALayer()
        bottomBorder.frame = CGRect(x: 0.0, y: textField.frame.size.height - 1, width: textField.frame.size.width, height: 1.0)
        if (textField.placeholder != "Birthday") {
            topBorder.frame = CGRect(x: 0.0, y: 0.0, width: textField.frame.size.width, height: 1.0)
        }
        bottomBorder.backgroundColor = (UIColor.gray).cgColor
        topBorder.backgroundColor = (UIColor.gray).cgColor
        textField.layer.addSublayer(bottomBorder)
        textField.layer.addSublayer(topBorder)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    //Carregar dades al perfil
    func loadUserProfile() {
        //indicador activitat
        self.startActivityIndicator()
        //iniciem consulta
        let query = PFUser.query()
        query?.findObjectsInBackground(block: { (objects, error) in
            //fi activitat
            self.stopActivityIndicator()
            if error != nil {
                print(error?.localizedDescription as Any)
            } else {
                
                //
                for object in objects! {
                    if let user = object as? PFUser {
                        if user.objectId == PFUser.current()?.objectId{
                            //let userId = user.objectId!
                            let name = user["name"]! as! String
                            let surname = user["surname"] as! String
                            let username = user.username!
                            let email = user.email!
                            let birthday = user["birthday"] as! Date
                            
                            //Omplim el array
                            //let myUser = User(userId: userId, name: name, surname: surname, username: username,email: email, birthday: birthday, image: nil)
                            
                            //Recuparem la Image i l'afegim a l'objecte
                            let image = user["image"] as! PFFile
                            image.getDataInBackground(block: { (data, error) in
                                if let data = data {
                                    let downloadImage = UIImage(data: data)
                                    print(downloadImage!)
                                    self.profileImageView.image = downloadImage
                                }
                            })
                            //self.users.append(myUser)
                            //Omplir les dades
                           // self.fillProfile(user: myUser)
                            
                            self.nameLabel.text = name
                            self.surnameLabel.text = surname
                            self.nameTextField.text = name
                            self.surnameTextField.text = surname
                            self.usernameTextField.text = username
                            self.emailTextField.text = email
                            
                            let formatter = DateFormatter()
                            formatter.dateStyle = .medium
                            formatter.timeStyle = .none
                            let birthdayForm = formatter.string(from: birthday)
                            self.birthdayTextField.text = birthdayForm
                    
                        }
                    }
                }
            }
        })
    }

    //Iniciar activityIndicator
    func startActivityIndicator(){
        //Aquí estem parant l'aplicació per enviar les dades a Parse i mostrar la roda de progres mentre esperem
        self.activityIndicator = UIActivityIndicatorView(frame: CGRect(x: 0, y: 0, width: 50, height: 50))
        self.activityIndicator.center = self.view.center
        self.activityIndicator.hidesWhenStopped = true
        self.activityIndicator.activityIndicatorViewStyle = .gray
        self.view.addSubview(self.activityIndicator)
        //Iniciem l'activity indicator
        self.activityIndicator.startAnimating()
        //Ignorem qualsevol toque a la pantalla mentre guardem les dades a parse
        UIApplication.shared.beginIgnoringInteractionEvents()
    }
    
    //Parar activityIndicator
    func stopActivityIndicator(){
        //Deixem d'ingorar els toques a pantalla i parem el activityIndicator
        self.activityIndicator.stopAnimating()
        UIApplication.shared.endIgnoringInteractionEvents()
    }
    
    //Funcio per crear alertes d'error
    func createAlert(title: String, message: String){
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(okAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    //Funcio per comprobar que introduim dades als camps user i password
    func infoCompleted() -> Bool {
        var infoCompleted = true
        
        if self.nameTextField.text == "" || self.surnameTextField.text == "" || self.usernameTextField.text == "" || self.emailTextField.text == "" || self.birthdayTextField.text == "" {
            infoCompleted = false
            self.createAlert(title: "Check the data",message: "Enter information for each field")
            
        }
        return infoCompleted
    }
    
}

//Ocultarà el teclat al deseleccionar els textfield. Es necessari assignar los delegados
extension UserProfileViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}



