//
//  SharedEventsDetailViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 12/6/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import Parse

class SharedEventsDetailViewController: UIViewController {

    //Variables
    var event : Event!
    
    //Outlet
    @IBOutlet weak var eventImage: UIImageView!
    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var joinButton: UIButton!
    
    //Action
    @IBAction func joinButton(_ sender: Any) {
        let query = PFQuery(className: "JoinEvent")
        query.whereKey("userId", equalTo: PFUser.current()?.objectId! as Any)
        query.whereKey("eventId", equalTo: self.event.eventId)
        query.findObjectsInBackground { (objects, error) in
            if let objects = objects {
                if objects != [] {
                    for object in objects {
                        //Esborrem la relació
                        object.deleteInBackground(block: { (success, error) in
                            if error == nil {
                                self.joinButton.setTitle("Join", for: .normal)
                                self.joinButton.backgroundColor = UIColor(red: 0/255, green: 128/255, blue: 64/255, alpha: 1.0)
                            } else {
                                print(error!.localizedDescription)
                            }
                        })
                    }
                } else {
                    let joinEvent = PFObject(className: "JoinEvent")
                    joinEvent["userId"] = PFUser.current()?.objectId
                    joinEvent["eventId"] = self.event.eventId
                    //Guardem la relacio
                    joinEvent.saveInBackground(block: { (success, error) in
                        if error == nil {
                            self.joinButton.setTitle("Not Join", for: .normal)
                            self.joinButton.backgroundColor = UIColor(red: 165/255, green: 4/255, blue: 7/255, alpha: 1.0)
                        } else {
                            print(error!.localizedDescription)
                        }
                    })
                    
                }
            }
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        //Omplim la informació de l'event
        self.fillEventDetails()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        //Ens preguntem: estem seguin l'event?
        self.isJoin()
    }
    
    func fillEventDetails(){
        self.eventImage.image = self.event.image
    }
    
    //Pintem el buttonJoin de verd o vermell segons isJoin
    func isJoin(){
        
        let query = PFQuery(className: "JoinEvent")
        query.whereKey("userId", equalTo: PFUser.current()?.objectId! as Any)
        query.whereKey("eventId", equalTo: self.event.eventId)
        query.findObjectsInBackground { (objects, error) in
            if let objects = objects {
                if objects != [] {
                    self.joinButton.setTitle("Not Join", for: .normal)
                    self.joinButton.backgroundColor = UIColor(red: 165/255, green: 4/255, blue: 7/255, alpha: 1.0)
                } else {
                    self.joinButton.setTitle("Join", for: .normal)
                    self.joinButton.backgroundColor = UIColor(red: 0/255, green: 128/255, blue: 64/255, alpha: 1.0)
                }
            } else {
                print(error!.localizedDescription)
            }
        }
    }


}

extension SharedEventsDetailViewController : UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 5
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "detailCell", for: indexPath) as! SharedEventsDetailTableViewCell
        
        switch indexPath.row {
        case 0:
            cell.keyLabel.text = "Title:"
            cell.valueLabel.text = self.event.title
        case 1:
            cell.keyLabel.text = "Description:"
            cell.valueLabel.text = self.event.descrip
        case 2:
            cell.keyLabel.text = "Category:"
            cell.valueLabel.text = self.event.category
        case 3:
            cell.keyLabel.text = "Location:"
            cell.valueLabel.text = self.event.location
        case 4:
            let formatter = DateFormatter()
            formatter.dateStyle = .medium
            formatter.timeStyle = .short
            cell.keyLabel.text = "Date:"
            cell.valueLabel.text = formatter.string(from: self.event.date)
        default:
            break
        }
        return cell
    }
}

extension SharedEventsDetailViewController : UITableViewDelegate {
    
}

