//
//  SharedEventsViewController.swift
//  HereTo
//
//  Created by Pol Martínez Maragall on 7/6/17.
//  Copyright © 2017 Parse. All rights reserved.
//

import UIKit
import Parse

class SharedEventsViewController: UITableViewController {

    //Variables
    var sharedEvents : [Event] = []
   
    //Outlet
    @IBOutlet weak var menuButton: UIBarButtonItem!
    
    
    override func viewDidLoad() {
        super.viewDidLoad()

        //refresh de la taula
        self.refreshControl = UIRefreshControl()
        self.refreshControl?.attributedTitle = NSAttributedString(string: "")
        self.refreshControl?.addTarget(self, action: #selector(UserEventsInfoViewController.reloadData), for: .valueChanged)
        
        //animacio buttonMenu
        if self.revealViewController() != nil {
            self.menuButton.target = self.revealViewController()
            self.menuButton.action = #selector(SWRevealViewController.revealToggle(_:))
            self.view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
        }
        
        self.loadEvents()
    }

    
    func reloadData(){
        
        self.tableView.reloadData()
        self.tableView.refreshControl?.endRefreshing()
    }
    
    func loadEvents() {
        self.sharedEvents.removeAll()
        let currentUserId = PFUser.current()!.objectId
        let query = PFQuery(className: "ShareEvent")
        query.whereKey("userId", equalTo: currentUserId!)
        query.addAscendingOrder("date")
        query.findObjectsInBackground { (objects, error) in
            if error == nil {
                if let objects = objects {
                    for object in objects {
                        let eventId = object["eventId"]!
                        let query = PFQuery(className: "Event")
                        query.whereKey("objectId", equalTo: eventId)
                        query.findObjectsInBackground(block: { (objects, error) in
                            if error == nil {
                                if let objects = objects {
                                    for object in objects {
                                        //Tots els elements
                                        let eventId = object.objectId!
                                        let title = object["title"] as! String
                                        let description = object["description"] as! String
                                        let image = object["image"] as! PFFile
                                        let userId = object["userId"] as! String
                                        let date = object["date"] as! Date
                                        let category = object["category"] as! String
                                        let location = object["location"] as! String
                                        let latitude = object["latitude"] as! Float
                                        let longitude = object["longitude"] as! Float
                                        //Posicio en array events
                                        let eventPosition = self.sharedEvents.count
                                        
                                        //Inicialitzem l'objecte Event
                                        let myEvent = Event(eventId: eventId, title: title, descrip: description, image: nil, userId: userId, date: date, category: category, location: location, latitude: latitude, longitude: longitude)
                                        
                                        //Recuparem la Image i l'afegim a l'objecte
                                        image.getDataInBackground(block: { (data, error) in
                                            if let data = data {
                                                let downloadImage = UIImage(data: data)
                                                self.sharedEvents[eventPosition].image = downloadImage
                                            }
                                        })
                                        //Afegim l'event al array
                                        self.sharedEvents.append(myEvent)
                                        self.tableView.reloadData()
                                    }
                                }
                            } else {
                                print(error!.localizedDescription)
                            }
                        })
                    }
                }
            } else {
                print(error!.localizedDescription)
            }
        }
    }
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.sharedEvents.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "sharedEventCell", for: indexPath) as! SharedEventsViewCell
        
        cell.eventImage.image = self.sharedEvents[indexPath.row].image
        cell.titleLabel.text = self.sharedEvents[indexPath.row].title
        cell.locationLabel.text = self.sharedEvents[indexPath.row].location
        let formatter = DateFormatter()
        formatter.dateStyle = .medium
        formatter.timeStyle = .short
        cell.dateLabel.text = formatter.string(from: self.sharedEvents[indexPath.row].date)

        return cell
    }

    override func tableView(_ tableView: UITableView, editActionsForRowAt indexPath: IndexPath) -> [UITableViewRowAction]? {
        
        let delete = UITableViewRowAction(style: .normal, title: "Delete") { (action, indexPath) in
            
            let eventIdDelete = self.sharedEvents[indexPath.row].eventId
            let query = PFQuery(className: "ShareEvent")
            query.whereKey("eventId", equalTo: eventIdDelete!)
            query.findObjectsInBackground(block: { (objects, error) in
                if error == nil {
                    for object in objects! {
                        object.deleteInBackground(block: { (success, error) in
                            if error == nil {
                                self.loadEvents()
                                self.tableView.reloadData()
                            } else {
                                print(error!.localizedDescription)
                            }
                        })
                    }
                } else {
                    print(error!.localizedDescription)
                }
            })
            
        }
        delete.backgroundColor = #colorLiteral(red: 0.7450980544, green: 0.1568627506, blue: 0.07450980693, alpha: 1)
        return [delete]
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "fromSharedEventToDetail" {
            if let sharedEventDetailController = segue.destination as? SharedEventsDetailViewController {
                if let indexPath = self.tableView.indexPathForSelectedRow {
                    sharedEventDetailController.event = self.sharedEvents[indexPath.row]
                }
            }
        }
    }


}
